#!/usr/bin/env python2

import shorah_dec
import optparse
import os

# parse command line
optparser = optparse.OptionParser()
opts = shorah_dec.main.func_defaults  # set the defaults (see http://bit.ly/2hCTQl)
group1 = optparse.OptionGroup(optparser, "Input files", "Required input")
group2 = optparse.OptionGroup(optparser, "Run options",
                              "Parameters that can (maybe should) be \
                              changed according to the needs")
group3 = optparse.OptionGroup(optparser, "More options",
                              "Do you really want to change this?")

group1.add_option("-b", "--bam",
                  help="file with aligned reads in .bam format",
                  default=opts[0], type="string", dest="in_bam")

group1.add_option("-f", "--fasta",
                  help="reference genome in fasta format",
                  default=opts[1], type="string", dest="in_fasta")

group2.add_option("-w", "--windowsize", help="window size <%default>",
                  default=opts[2], type="int", dest="win_length")

group3.add_option("-s", "--winshifts",
                  help="number of window shifts <%default>",
                  default=opts[3], type="int", dest="win_shifts")

group2.add_option("-r", "--region",
                  help="region in format 'chrom:start-stop', \
                  eg 'ch3:1000-3000'",
                  default=opts[4], type="string", dest="region")

group3.add_option("-x", "--maxcov",
                  help="approximate max coverage allowed <%default>",
                  default=opts[5], type="int", dest="max_coverage")

group2.add_option("-a", "--alpha",
                  help="alpha in dpm sampling <%default>",
                  default=opts[6], type="float", dest="alpha")

group3.add_option("-k", "--keep_files",
                  help="keep all intermediate files <%default>",
                  action="store_true", dest="keep_files",
                  default=opts[7])

optparser.add_option_group(group1)
optparser.add_option_group(group2)
optparser.add_option_group(group3)

(options, args) = optparser.parse_args()

supported_formats = {
    'bam': 'aligned reads',
    'fasta': 'reference genome'
}
# check the input file is in supported format
try:
    tmp_filename = os.path.split(options.in_bam)[1]
    [in_stem, in_format] = [tmp_filename.split('.')[0],
                            tmp_filename.split('.')[-1]]
    t = supported_formats[in_format]
except IndexError:
    shorah_dec.declog.error('The input file must be filestem.format')
    print 'The input file must be filestem.format'
    print 'Supported formats are'
    for sf in supported_formats.iteritems():
        print sf[0], ':', sf[1]
    sys.exit()
except KeyError:
    shorah_dec.declog.error('format unknown')
    print in_format, 'format unknown'
    print 'Supported formats are'
    for sf in supported_formats.iteritems():
        print sf[0], ':', sf[1]
    sys.exit()
shorah_dec.main(*args, **vars(options))
